c	Source description type 
c
c  MDSPMOD=1 : emissions file output is for CALPUFF
c          2 : emissions file output is for AERMOD
c
c      
c  MINPUT =1 : source  conditions are input and 
c	               blowdown is calculated (see MBLOWDOWN)
c	           2 : blowdown curve sequence is input
c			   3 : static source is input (see GROUP SOURCE)
c		default : 1
c
c                    only used if MINPUT =1
c MBLOWDOWN=1 : user input QMAX and QTOTAL
c	   		     2 : blowdown exponential model 
c	   				 parameters are calculated from pipeline/vessel 
c	   				 initial conditions
c		default : 2  
c
c		only used if MINPUT =1
c MDIST=1 : blowdown sequence is created based upon
c				 puffs of equal volume
c	         2 : blowdown sequence is created based upon
c				 puffs of equal mass
c		default : 2  
c
c MSTRIP=0 : source is described by input (100% conversion to SO2)
c	         =1 : source is a stripped flow source (H2S)
c			 =2 : source is actual SO2 (accounting for efficiency)
c
c MMET=1:  meteorology is read from METPATH, METSERIES style
c     =2:  meteorology is read from METPATH, aermet style
c     =3:  force met to be WINDSP, WINDDR, TAMB 
c
c MFUELGAS: Is fuel gas added?
c		0 = no fuel gas is added
c		1 = fuel gas is added
c
c MLIFTGAS: Is lift gas added?
c		0 = no lift gas is added
c		1 = lift gas is added
c
c 
c MFGR =1 : fuel gas is proportional to qmax rate 
c            =2 : fuel gas is constant amount based upon initial qmax  
c		default : 2
c
c
c MFASSIST
c      Is flare assist used ?
c		0 = no flare assist
c		1 = steam assist 
c		2 = air assist
c		3 = both steam and air assist is used
c
      integer :: MDSPMOD         ! output is for 1:CALPUFF; 2:AERMOD
      integer :: MINPUT         ! 
      integer :: MBLOWDOWN      ! 
      integer :: MDIST          !
      integer :: MFGR           !
      integer :: MSTRIP         !
      integer :: MMET           !
	  integer :: MFASSIST		! iflareassist:0 no assist; 1=steam; 2=air; 3=both
	  integer :: MFUELGAS		! 0: no fuel gas is added; 1:user fuel gas is added
	  integer :: MLIFTGAS		! 0: no lift gas ; 1:liftgas is added
	  integer :: MDEBUG			! 0: no debug   1: debug

      integer :: iyys, imms, idds, ihhs, isss, ijjs, idatestart
      integer :: iyye, imme, idde, ihhe, isse, ijje, idateend
      integer :: itiminc
      integer :: nspec
      real(8) ::      mmlst(mxchem)  ! mole weight list 
      real(8) ::      qlst(mxchem)   ! emissions list
      real(8) :: xcoord			! location of source km-UTM
      real(8) :: ycoord			! location of source km-UTM
      real(8) :: zcoord			! elevation of source m
      real(8)  :: hs               ! actual height,m 
      real(8)  :: ds               ! actual diameter, m
      real(8)  :: pshs             ! pseudo-height,m
      real(8)  :: psds             ! pseudo-diameter, m
      real(8)  :: psus             ! pseudo-velocity, m/s
      real(8)  :: psts             ! pseudo-temperature, K
      real(8)  :: rh2s             ! mole fraction of H2S
      real(8) :: tginit		!  Initial flared (raw and fuel) Gas Temperature	K 
      real(8)  :: qmax             ! peak rate for blowdown curve, e3m3/d
      real(8)  :: qtotal           ! total volume in pipeline/vessel, e3m3
      real(8)  :: duration         ! duration of flare event, h
      real(8)  :: frel             ! fraction left in pipeline/vessel
	real(8) :: pressinit		!  Expected Maximum Initial Pressure	kPa (gauge)
      real(8) :: tempinit		!  Expected Minimum Initial Gas Temperature	K 
	real(8) :: pressfinal		!  Expected Minimum Final Pressure	kPa
	real(8) :: vesseldia		!  Pipeline/Vessel Inside Diameter	m
	real(8) :: vessellen		!  Pipeline/Vessel Length	m
	real(8) :: orificedia		!  Minimum Orifice Diameter	mm
	real(8) :: dischargecoef	!  Discharge Coefficient	

      real(8)  :: rWINDSP     ! user wind speed static, m
      real(8)  :: rWINDDR     ! user wind dir static, m/s 
      real(8)  :: rTAMB       ! user temperature ambient static K
      real(8)  :: rqemit      ! emission rate, kg/s
      real(8)  :: rzref       ! user zref, m
      integer  :: irPGCLASS
      integer  :: ipuffdur    ! number of seconds duration
      integer  :: npuffs
      real(8)  :: fgr
      real(8)  :: gcraw(mxcomp)
      real(8)  :: gcfuel(mxcomp)
      real(8)  :: gclift(mxcomp)
      real(8)  :: pseq(4,mxpuff)

      real(8) :: qliftgas	! lift gas flow rate e3m3/d
      real(8) :: stm_dia			! steam assist individual port diameter [m]
      real(8) :: stm_press		! steam assist pressure of steam or -1 if unknown
      real(8) :: stm_temp		! steam assist temperature of steam or -1 if unknown
      real(8) :: stm_flow		! steam assist mass flow rate kg/s or flow rate e3m3/d
      real(8) :: air_dia			! air assist individual port diameter[m]
	real(8) :: air_flow		! air assist flow rate e3m3/d
	integer :: stm_nports	! number of steam assist injection ports
	integer :: stm_imassvol	! steam assist is 1=mass flow; 2=volume flow
	integer :: air_nports	! number of air assist injection ports
      integer :: nsep		! separation 24,48,72,...
	integer :: nsources	! number of aermod sources
	integer :: nseq		! length of user defined blowdown sequence

      character*128 :: stitle
      character*32 :: sname
      CHARACTER*1 :: UTMHEM
      CHARACTER*6 :: PMAP
      CHARACTER*6 :: DATUM
	  CHARACTER*4 :: UNITS
      character*8 :: ABTZ
      character*8 :: chemlst(mxchem)
      character*255 :: METDAT
      character*255 :: METDAT2
      character*255 :: OUTNAME
      character*255 :: OUTPATH
      character*255 :: LSTDAT
      character*255 :: LOGDAT

	  logical :: lcfiles	! T: convert all files to lower case
							! F: do not
      common /read1/  
     &  xcoord, ycoord, zcoord, 
     &  hs, ds, pshs, psds, psus, psts, 
     &  rh2s, tginit, qmax, qtotal, duration, frel,
     &  pressinit, tempinit,pressfinal, vesseldia, vessellen,
     &  orificedia, dischargecoef,
     &  fgr, qliftgas, rwindsp, rwinddr, rtamb, rqemit, rzref,
     &  gcraw, gcfuel, gclift,
     &  pseq,
     &  mmlst, qlst, 
     &  stm_dia, stm_press, stm_temp, stm_flow, air_dia,air_flow,
     &  stm_nports, stm_imassvol, air_nports, 
     &  iutmzn, nspec, 
     &  iyys, imms, idds, ihhs, isss, ijjs, idatestart,
     &  iyye, imme, idde, ihhe, isse, ijje, idateend,
     &  itiminc,
     &  npuffs, ipuffdur, irpgclass, mfuelgas, mliftgas, MFASSIST,
     &  MDEBUG,NSEP,NSOURCES,nseq,
     &  MDSPMOD, MINPUT, MBLOWDOWN, MDIST, MFGR, MSTRIP, MMET

	  common /read3/  
     &  stitle, sname, PMAP, ABTZ, 
     &  UNITS, DATUM, METDAT, METDAT2, OUTNAME, OUTPATH, LSTDAT, LOGDAT,
     &  chemlst, UTMHEM  

      common /read2/  lcfiles

