c-----------------------------------------------------------------------
      module header
c-----------------------------------------------------------------------
c --- CALAVE    Version: 1.1            Level: 120702          /HEADER/
c               D. Strimaitis, Exponent Inc.
c
c --- Header Data from input CALPUFF CONC/WET/DRY files
c --- Use variable names as listed in the CALPUFF Users Guide
c
c --- Use arrays for ALL variables so that information from multiple
c --- data files can be stored (allocate)
c-----------------------------------------------------------------------

      logical, allocatable :: lcompr(:),lsamp(:),ldisc(:),lctsg(:),
     &                        lspunit(:)

      character*12,  allocatable :: cmodel(:),ver(:),level(:)
      character*4,   allocatable :: utmhem(:)
      character*8,   allocatable :: pmap(:),datum(:),axbtz(:)
      character*12,  allocatable :: daten(:)
      character*15,  allocatable :: csout(:,:)
      character*16,  allocatable :: clat0(:),clon0(:),clat1(:),clat2(:)
      character*16,  allocatable :: dataset(:),dataver(:)
      character*16,  allocatable :: csunit(:,:)
      character*16,  allocatable :: cnampt1(:,:),cnampt2(:,:)
      character*16,  allocatable :: cnamar1(:,:),cnamar2(:,:)
      character*16,  allocatable :: cnamln1(:,:),cnamln2(:,:)
      character*16,  allocatable :: cnamvl1(:,:),cnamvl2(:,:)
      character*64,  allocatable :: datamod(:)
      character*80,  allocatable :: title(:,:)

      integer, allocatable :: ncom(:),ibyr(:),ibjul(:),ibhr(:),ibsec(:),
     &                        irlg(:),iavg(:),nsecdt(:),
     &                        nxm(:),nym(:),nz(:),nssta(:),
     &                        ibcomp(:),iecomp(:),jbcomp(:),jecomp(:),
     &                        ibsamp(:),jbsamp(:),iesamp(:),jesamp(:),
     &                        meshdn(:),npt1(:),npt2(:),nar1(:),nar2(:),
     &                        nln1(:),nln2(:),nvl1(:),nvl2(:),
     &                        msource(:),ndrec(:),nctrec(:),nspout(:),
     &                        i2dmet(:),iutmzn(:),ihill(:,:),
     &                        nsrc(:),ngx(:),ngy(:)
      
      real, allocatable :: xbtz(:),dxkm(:),dykm(:),xorigkm(:),
     &                     yorigkm(:),feast(:),fnorth(:),rnlat0(:),
     &                     relon0(:),xlat1(:),xlat2(:),
     &                     xrec(:,:),yrec(:,:),zrec(:,:),
     &                     xctr(:,:),yctr(:,:),zctr(:,:)

      end module header


c-----------------------------------------------------------------------
      module userinf
c-----------------------------------------------------------------------
c --- CALAVE    Version: 1.1            Level: 120915         /USERINF/
c               D. Strimaitis, Exponent Inc.
c
c --- Control file information
c
c --- UPDATES:
c --- v1.0 (120702) to v1.1 (120915)
c        1. Change pathname variables from C*132 to C*256
c-----------------------------------------------------------------------

      logical :: lcfiles

      character(len=256), allocatable :: inpfile(:), outfile(:)
      character(len=256)              :: lstfile
      character(len=40)               :: out_ext
      character(len=4)                :: start_hhmm

      integer :: avgpd_hh,avgpd_mm
      integer :: mode,nfiles
      integer :: navgpd                                                 ! Calculated
      integer :: start_hour,start_minute
      integer :: start_second                                           ! 0 - 3540

c --- Establish initial (default) values
      data lcfiles/.FALSE./
      data start_hhmm/'0000'/
      data mode/0/, avgpd_hh/0/, avgpd_mm/0/
      data out_ext/'.ave'/

      end module userinf


c-----------------------------------------------------------------------
      module inpdata
c-----------------------------------------------------------------------
c --- CALAVE    Version: 1.1            Level: 120702            /DATA/
c               D. Strimaitis, Exponent Inc.
c
c --- Data from input CALPUFF CONC/WET/DRY files
c --- Use variable names as listed in the CALPUFF Users Guide
c-----------------------------------------------------------------------

      character(len=16), allocatable :: sname(:,:)                      ! (sources,files)
      character(len=15), allocatable :: cspecg(:,:)                     ! (spec-lev,files)
      character(len=15), allocatable :: cspecd(:,:)                     ! (spec-lev,files)
      character(len=15), allocatable :: cspecct(:,:)                    ! (spec-lev,files)

      integer, allocatable :: istype(:,:),isnum(:,:)                    ! (sources,files)
      integer, allocatable :: nyrb(:,:),njulb(:,:),nhrb(:,:),nsecb(:,:) ! (times,files)
      integer, allocatable :: nyre(:,:),njule(:,:),nhre(:,:),nsece(:,:) ! (times,files)

      real, allocatable :: sxkm(:,:),sykm(:,:)                          ! (sources,files)
      real, allocatable :: datag(:,:,:,:,:,:)                           ! (ngx,ngy,spec-lev,sources,times,files)
      real, allocatable :: datad(:,:,:,:,:)                             ! (ndrec,spec-lev,sources,times,files)
      real, allocatable :: datact(:,:,:,:,:)                            ! (nctrec,spec-lev,sources,times,files)

      real, allocatable :: workg(:,:)                                   ! (ngx,ngy)
      real, allocatable :: workd(:)                                     ! (ndrec)
      real, allocatable :: workct(:)                                    ! (nctrec)

      end module inpdata

c-----------------------------------------------------------------------
      module avgdata
c-----------------------------------------------------------------------
c --- CALAVE    Version: 1.1            Level: 120702         /AVGDATA/
c               D. Strimaitis, Exponent Inc.
c
c --- Averages for output CALPUFF CONC/WET/DRY files
c-----------------------------------------------------------------------

      real, allocatable :: avgdatag(:,:,:,:)                              ! (nxg,nyg,spec-lev,sources)
      real, allocatable :: avgdatad(:,:,:)                                ! (ndrec,spec-lev,sources)
      real, allocatable :: avgdatact(:,:,:)                               ! (nctrec,spec-lev,sources)

      end module avgdata

